==> lib-colorifium-0.2.2.tgz: package/converters/hsl.js <==
import { HueHelper } from '../util/helpers';
import { FromRGBF } from './rgbf';
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSL colour space is known as HSB in Photoshop.
 */
export class FromHSL {
    static toRGBF(h, s, l) {
        const args = FromHSL.resolveArguments(h, s, l);
        if (args.s === 0) {
            return {
                r: l,
                g: l,
                b: l
            };
        }
        else {
            const C = (1 - Math.abs(2 * args.l - 1)) * args.s;
            const X = C * (1 - Math.abs((args.h / 60) % 2 - 1));
            const m = args.l - C / 2;
            if (args.h < 60) {
                return HueHelper.hueToRgbMatrix(C, X, 0, m);
            }
            else if (args.h < 120) {
                return HueHelper.hueToRgbMatrix(X, C, 0, m);
            }
            else if (args.h < 180) {
                return HueHelper.hueToRgbMatrix(0, C, X, m);
            }
            else if (args.h < 240) {
                return HueHelper.hueToRgbMatrix(0, X, C, m);
            }
            else if (args.h < 300) {
                return HueHelper.hueToRgbMatrix(X, 0, C, m);
            }
            else {
                return HueHelper.hueToRgbMatrix(C, 0, X, m);
            }
        }
    }
    static toRGB8(h, s, l) {
        return FromRGBF.toRGB8(FromHSL.toRGBF(h, s, l));
    }
    static resolveArguments(h, s, l) {
        const argumentType = typeof h;
        let result;
        if (argumentType === 'object' && h !== null) {
            result = { h: h.h, s: h.s, l: h.l };
        }
        else if (argumentType === 'number') {
            result = { h: h, s: s, l: l };
        }
        else {
            throw new TypeError('Unknown arguments passed');
        }
        return result;
    }
}

==> lib-colorifium-0.4.1.tgz: package/converters/hsl.js <==
import { HueHelper } from '../util/helpers';
import { FromRGBF } from './rgbf';
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSL colour space is known as HSB in Photoshop.
 */
export class FromHSL {
    static toRGBF(h, s, l) {
        const args = FromHSL.resolveArguments(h, s, l);
        if (args.s === 0) {
            return {
                r: l,
                g: l,
                b: l
            };
        }
        else {
            const C = (1 - Math.abs(2 * args.l - 1)) * args.s;
            const X = C * (1 - Math.abs((args.h / 60) % 2 - 1));
            const m = args.l - C / 2;
            if (args.h < 60) {
                return HueHelper.hueToRgbMatrix(C, X, 0, m);
            }
            if (args.h < 120) {
                return HueHelper.hueToRgbMatrix(X, C, 0, m);
            }
            if (args.h < 180) {
                return HueHelper.hueToRgbMatrix(0, C, X, m);
            }
            if (args.h < 240) {
                return HueHelper.hueToRgbMatrix(0, X, C, m);
            }
            if (args.h < 300) {
                return HueHelper.hueToRgbMatrix(X, 0, C, m);
            }
            return HueHelper.hueToRgbMatrix(C, 0, X, m);
        }
    }
    static toRGB8(h, s, l) {
        return FromRGBF.toRGB8(FromHSL.toRGBF(h, s, l));
    }
    static resolveArguments(h, s, l) {
        const argumentType = typeof h;
        if (argumentType === 'object' && h !== null) {
            return { h: h.h, s: h.s, l: h.l };
        }
        if (argumentType === 'number') {
            return { h: h, s: s, l: l };
        }
        throw new TypeError('Unknown arguments passed');
    }
}
